# SNUPy
## Author: Rohan Singh
SNUPy is an open-source machine learning API written in Python. The main goal of SNUPy is to be a simple and flexible API for machine learning.  

SNUPy stands for:  
**S**NUPy **N**ever **U**sed **Py**thon

This package is dedicated to my closest stuffed Animal, Snoopy :)

## Installation  
**<a href="https://test.pypi.org/project/SNUPy/1.0.1/"> Click Here </a>** to go tp the PyPI (Python Package Index) link to this project.   

To install the SNUPy library you must use the Pip package installer.  

To make sure you have the latest version of pip run the following command:  
  - **For MacOS/UNIX/Linux:**  
    > python3 -m pip install --upgrade pip  
  - **For Windows:**  
    > py -m pip install --upgrade pip

### UNIX/MacOS/Linux
  > python3 -m pip install SNUPy==1.0.2

### Windows
  > py -m pip install SNUPy==1.0.2 
  

  
## Contact
For any feedback, suggestions or questions, contact me at:  
rxs1182@case.edu   
rohan.b.singh54@gmail.com
